aboutsummaryrefslogtreecommitdiffstats
path: root/shell/e-shell-window.h
diff options
context:
space:
mode:
Diffstat (limited to 'shell/e-shell-window.h')
-rw-r--r--shell/e-shell-window.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/shell/e-shell-window.h b/shell/e-shell-window.h
index f9cdb60cf4..d78fb19774 100644
--- a/shell/e-shell-window.h
+++ b/shell/e-shell-window.h
@@ -100,16 +100,16 @@ void e_shell_window_set_safe_mode (EShellWindow *shell_window,
void e_shell_window_add_action_group (EShellWindow *shell_window,
const gchar *group_name);
/* These should be called from the shell module's window_created() handler. */
void e_shell_window_register_new_item_actions
(EShellWindow *shell_window,
- const gchar *module_name,
+ const gchar *backend_name,
GtkActionEntry *entries,
guint n_entries);
void e_shell_window_register_new_source_actions
(EShellWindow *shell_window,
- const gchar *module_name,
+ const gchar *backend_name,
GtkActionEntry *entries,
guint n_entries);
@@ -100,16 +100,16 @@ void e_shell_window_set_safe_mode (EShellWindow *shell_window,
void e_shell_window_add_action_group (EShellWindow *shell_window,
const gchar *group_name);
-/* These should be called from the shell module's window_created() handler. */
+/* These should be called from the shell backend's window_created() handler. */
void e_shell_window_register_new_item_actions
(EShellWindow *shell_window,